Learn R Programming

paleofire (version 1.1.8)

checkGCDversion: Check GCD package install

Description

Check if GCD package is installed and up to date to ensure always using the most up to date GCD version. devtools package is required: on Windows install Rtools.exe depending on your R version http://cran.r-project.org/bin/windows/Rtools/

Usage

checkGCDversion()

Arguments

Details

Last GCD database version is donwloaded and installed using:

library(devtools)

install_github("GCD",username="paleofire",ref="master")

Examples

Run this code

## Not run: checkGCDversion()

Run the code above in your browser using DataLab